CacheDecodeException class final

Thrown by CacheCodec.decode when the bytes cannot be decoded.

Implemented types

Constructors

CacheDecodeException(String message, {Object? cause})
const

Properties

cause → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited