CacheMiss<V> class
final
The key was not found, or the entry was hard-expired and removed.
- Inheritance
-
- Object
- CacheResult<
V> - CacheMiss
Constructors
- CacheMiss()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited