MemoryPressureConfig class final

Configures how MemoryCachePressureWatcher responds to OS memory signals.

Constructors

MemoryPressureConfig({double moderateEvictionFraction = 0.20, double criticalEvictionFraction = 0.50, bool ignoreBackgroundPressure = true})
const

Properties

criticalEvictionFraction double
Fraction of LRU entries to evict on a critical pressure signal (0.0–1.0).
final
hashCode int
The hash code for this object.
no setterinherited
ignoreBackgroundPressure bool
When true (default), memory pressure signals received while the app is backgrounded are ignored.
final
moderateEvictionFraction double
Fraction of LRU entries to evict on a moderate pressure signal (0.0–1.0).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited